# RentcastMarketStatistics200ResponseRentalDataHistory


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_2025_06** | [**RentcastMarketStatistics200ResponseRentalDataHistory202506**](RentcastMarketStatistics200ResponseRentalDataHistory202506.md) |  | [optional] 
**var_2025_07** | [**RentcastMarketStatistics200ResponseRentalDataHistory202507**](RentcastMarketStatistics200ResponseRentalDataHistory202507.md) |  | [optional] 
**var_2025_08** | [**RentcastMarketStatistics200ResponseRentalDataHistory202508**](RentcastMarketStatistics200ResponseRentalDataHistory202508.md) |  | [optional] 

## Example

```python
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history import RentcastMarketStatistics200ResponseRentalDataHistory

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastMarketStatistics200ResponseRentalDataHistory from a JSON string
rentcast_market_statistics200_response_rental_data_history_instance = RentcastMarketStatistics200ResponseRentalDataHistory.from_json(json)
# print the JSON string representation of the object
print(RentcastMarketStatistics200ResponseRentalDataHistory.to_json())

# convert the object into a dict
rentcast_market_statistics200_response_rental_data_history_dict = rentcast_market_statistics200_response_rental_data_history_instance.to_dict()
# create an instance of RentcastMarketStatistics200ResponseRentalDataHistory from a dict
rentcast_market_statistics200_response_rental_data_history_from_dict = RentcastMarketStatistics200ResponseRentalDataHistory.from_dict(rentcast_market_statistics200_response_rental_data_history_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


